// UserBody.h++

#ifndef _UserBody_H_
#define _UserBody_H_

#include <iostream.h>

#include <Inventor/nodes/SoSeparator.h>
#include <Inventor/nodes/SoMaterial.h>
#include <Inventor/nodes/SoRotationXYZ.h>
#include <Inventor/nodes/SoCone.h>
#include <Inventor/nodes/SoTransform.h>
#include <Inventor/nodes/SoText3.h>
#include <Inventor/nodes/SoFont.h>
#include <Inventor/nodes/SoSphere.h>
#include <Inventor/nodes/SoTexture2.h>
#include <Inventor/engines/SoCompose.h>

class UserBodyObject
{
public:
    SoSeparator* ball;
    SoSphere* shape;
    SoTransform* xform1;
    SoTransform* xform2;
    SoMaterial* material;
    SoSeparator* textRoot;
    SoText3* text;
    SoTransform* textXform;
    SoFont *textFont;
    UserBodyObject();
    void setOrientation( float theta ) {
	xform2 -> scaleOrientation.setValue(SbVec3f(0.,0.,1.), theta ); }
    void setSize( float x, float y ) {
	xform2 -> scaleFactor.setValue( x, y, 1.0 ); }
    void setLocation( float x, float y, float z ) {
	xform1 -> translation.setValue( x, y, z ); }
    void setText( char* msg ) {
	text -> string = msg; }
    void setColor( float r, float g, float b ) {
	material -> diffuseColor.setValue( r/255.0, g/255.0, b/255.0 ); }
    SoNode* getNode() { return ball; }
	
};

class UserBody
{
  SoSeparator *body;
  UserBodyObject objects[7];

public:
  UserBody();
  ~UserBody();
    enum { RHAND=0, LHAND, HEAD, RFOOT, LFOOT, CHEST, WAIST };
    inline void setLocation( int which , float , float, float );
    inline void setText( int which, char* msg );
    inline void setColor( int which, float , float, float );
    inline void setSize( int which, float , float );
    inline void setOrientation( int which, float );
    
  operator SoNode*() { return body; }
  SoNode* getNode() { return body; }
};


inline
void
UserBody::setLocation( int which, float x, float y, float z )
{
    objects[ which ].setLocation( x, y, z );
    //    cerr << which << " locat is " << x << " " << y << " " << z << endl;
}


inline
void
UserBody::setText( int which, char* msg )
{
    objects[ which ].setText( msg );
}

inline
void
UserBody::setColor( int which, float r, float g, float b )
{
    objects[ which ].setColor( r, g, b );
    //    cerr << which << " color is " << r << " " << g << " " << b << endl;
}

inline
void
UserBody::setSize( int which, float x, float y )
{
  objects[ which ].setSize( y, x);
    //    cerr << which << " size  is " << x << " " << y << endl;
}

inline
void
UserBody::setOrientation( int which, float theta )
{
    objects[ which ].setOrientation( theta );
    //    cerr << which << " angle is " << theta << endl;
}

#endif // _UserBody_H_



